@@ -26,7 +26,10 @@ def toggl_to_redmine(config):
                 redmine.save_entry(time_entry)
                 entries_logged.append(time_entry)
             except RedmineIntegrationException as e:
-                time_entry.message = str(e)
+                msg = str(e)
+                if msg == None or msg == '':
+                    msg = 'Redmine integration failed'
+                time_entry.message = msg
                 entries_not_logged.append(time_entry)
         else:
             entries_not_logged.append(time_entry)
